<template>
  <div>
    <el-dialog custom-class="bbsl-location-dialog" top="8vh" :close-on-click-modal="false" :title="title"
               v-if="visible" :visible="visible" width="1200px" :before-close="handleClose">

      <div class="bbsl-scroll-pane">
        <el-form class="bbsl-scroll-form" ref="formInfo" :rules="rules" :model="params"
                 label-width="100px">
          <el-row>
            <el-col :span="8">
              <el-form-item label="考核年度：" :rules="[
                                        {
                                            required: true,
                                            message: '请选择考核年度',
                                        },
                                    ]">
                <el-select popper-class="scorll" v-model="params.assessYear" style="width: 100%"
                           @clear="remove()" @change="changeAssessYear($event)" placeholder="请选择考核年度"
                           clearable>
                  <el-option v-for="item in assessYear" :key="item" :label="item"
                             :value="item">
                  </el-option>
                </el-select>
              </el-form-item>
            </el-col>
            <el-col :span="8">
              <el-form-item label="考核标题：" prop="baseId">
                <el-select popper-class="scorll" v-model="params.baseId"
                           :disabled="params.assessYear ? false : true" style="width: 100%"
                           @clear="remove()" @change="changeAssessTitle($event)" placeholder="请选择考核标题"
                           clearable>
                  <el-option v-for="item in assessTitleList" :key="item.id"
                             :label="item.assessTitle" :value="item.id">
                  </el-option>
                </el-select>
              </el-form-item>
            </el-col>
            <el-col :span="8">
              <el-form-item label="考核人员：" prop="assessUser">
                <el-input clearable placeholder="请输入考核人员" maxlength="64"
                          v-model="params.assessUser"></el-input>
              </el-form-item>
            </el-col>
            <el-col :span="8">
              <el-form-item label="被考核者：" prop="reference">
                <el-select popper-class="scorll" v-model="params.reference"
                           :disabled="params.assessYear && params.assessTitle ? false : true"
                           style="width: 100%" placeholder="请选择被考核者" clearable>
                  <el-option v-for="(item, index) in referenceList" :key="index" :label="item"
                             :value="item">
                  </el-option>
                </el-select>
              </el-form-item>
            </el-col>
            <el-col :span="8">
              <el-form-item label="考核日期：" prop="assessDate">
                <el-date-picker clearable style="width: 100%" value-format="yyyy-MM-dd"
                                placeholder="请输入考核日期" v-model="params.assessDate"></el-date-picker>
              </el-form-item>
            </el-col>
          </el-row>
        </el-form>
      </div>
      <!-- <div style="margin-bottom:10px">
<el-button icon="el-icon-plus" type="primary" @click="addAcounts">
添加
</el-button>
</div> -->
      <el-table :row-key="getRowKey" ref="multipleSelections" border v-loading="loading"
                :data="params.detailsList" :row-style="{ height: '61px' }" style="width: 100%"
                :header-cell-style="{ 'text-align': 'center' }" :cell-style="{ 'text-align': 'center' }">
        <el-table-column label="序号" type="index" width="50"></el-table-column>
        <el-table-column  prop="item" label="考核项" show-overflow-tooltip></el-table-column>
        <el-table-column prop="itemScore" label="考核项评分" width="260">
          <!-- <template slot-scope="scope">
              <el-input
                  clearable
                  v-model="scope.row.itemScore"
                  placeholder="请输入考核项评分"
              ></el-input>
          </template> -->
          <template slot-scope="scope">
            <el-form :model="scope.row">
              <el-form-item label="" prop="itemScore" :rules="validateTaskName">
                <el-input clearable type="number" min="1" max="100"
                          v-model="scope.row.itemScore" placeholder="评分范围1-100"></el-input>
              </el-form-item>
            </el-form>
          </template>
        </el-table-column>
      </el-table>

      <span slot="footer" class="dialog-footer">
                <el-button type="primary" @click="goInfo">保 存</el-button>
                <el-button @click="handleClose">取 消</el-button>
            </span>
    </el-dialog>
  </div>
</template>
<script>
import operationCheck from '@/api/device/operationCheck.js'
import resourceManage from '@/api/device/resourceManage.js'
import req from '@/api/device/contractManage.js'

export default {
  name: 'UnitCheckDialog',
  components: {},
  data() {
    var checkName = (rule, value, callback) => {
      if (value == '' || value == undefined || value == null) {
        callback()
      } else if (!Number(value)) {
        callback(new Error('请输入[1,100]之间的数字'))
      } else if (value < 1 || value > 100) {
        callback(new Error('请输入[1,100]之间的数字'))
      } else {
        callback()
      }
    }
    return {
      validateTaskName: [
        {
          required: true,
          message: '请输入1~100之间的考核项评分',
          trigger: 'blur',
          validator: checkName
        },
        {required: true, message: '输入不能为空', trigger: 'blur'}
      ],
      visible: false,
      title: '新增',
      activeCollapse1: '1',
      tableData: [],
      multipleSelections: [],
      assessTitleList: [],
      assessYear: [], //考核年度
      baseYear: null, //选择年份
      activeId: null, //考核标题id
      params: {
        detailsList: [],
        reference: '', // 被考核人者
        assessTitle: '',
        assessYear: '',
        assessDate: '', // 考核日期
        assessType: '2', // 考核方式（1：单位考核，2：合同考核）
        assessUser: '' // 考核人员
      },
      itemsData: [],
      loading: false,
      dialogLoading: false,
      referenceList: [], // 被考核者列表
      queryParam: {
        pageBean: {
          pageSize: -1
        }
      },
      rules: {
        assessUser: [
          {
            required: true,
            message: '请输入考核人',
            trigger: 'blur'
          }
        ],
        assessDate: [
          {
            required: true,
            message: '请选择考核日期',
            trigger: 'blur'
          }
        ],
        reference: [
          {
            required: true,
            message: '请输入被考核者',
            trigger: 'blur'
          }
        ]
      }
    }
  },
  created() {
    // this.getContractCheckData()
  },
  methods: {
    //选择年度
    changeAssessYear(val) {
      this.params.detailsList = []
      this.assessTitleList.forEach((item) => {
        if (item.id == this.activeId && item.assessYear == val) {
          item.itemsList.forEach((item) => {
            this.params.detailsList.push({
              infoId: item.baseId,
              item: item.item,
              itemId: item.id,
              itemScore: '',
              pkVal: item.pkVal,
              memo: item.memo,
              itemVal: item.itemVal
            })
          })
        }
      })
    },
    //指定一个key标识这一行的数据
    getRowKey(row) {
      return row.id
    },
    add() {
      this.visible = true
      this.title = '新增'
      this.getAppraiseItems()
    },
    edit(row) {
      this.visible = true
      this.title = '修改'
      this.dialogLoading = true
      operationCheck.getInfoById(row.id, (res) => {
        this.params = res
        console.log(this.params)
        this.getAppraiseItems()
        this.dialogLoading = false
      })
    },
    remove() {
      this.params.detailsList = []
    },
    changeAssessTitle(val) {
      this.params.detailsList = []
      this.assessTitleList.forEach((item) => {
        if (item.id == val && item.assessYear == this.params.assessYear) {
          this.params.assessTitle = item.assessTitle
          item.itemsList.forEach((item) => {
            this.params.detailsList.push({
              infoId: item.baseId,
              item: item.item,
              itemId: item.id,
              itemScore: '',
              pkVal: item.pkVal
            })
          })
        }
      })
      this.getContractCheckData()
    },
    getAppraiseItems() {
      this.loading = true
      let data = {
        pageBean: {
          page: -1,
          pageSize: 10,
          showTotal: true
        },
        querys: [
          {
            group: 'main',
            operation: 'EQUAL',
            property: 'dab.assess_type_',
            relation: 'AND',
            value: '2'
          },
          {
            group: 'main',
            operation: 'EQUAL',
            parentGroup: '',
            property: 'publish_status_',
            relation: 'AND',
            value: '1'
          }
        ]
      }
      operationCheck.loadAppraiseItems(data, (res) => {
        // 获取当前登录人名称
        let currentUser = JSON.parse(
          window.sessionStorage.getItem('currentUser')
        )
        this.params.assessUser = currentUser.username
        // 设置考核日期为当前时间
        this.params.assessDate = this.getDate()
        // this.params.reference = this.referenceList[0].contractName
        this.assessTitleList = res.rows
        var arrYear = []
        // let tempDetailsList = []
        arrYear.push(
          this.assessTitleList.map((item) => {
            // if (item.assessTitle == this.params.assessTitle) {
            //     tempDetailsList = item.itemsList
            // }
            return item.assessYear
          })
        )
        // this.params.detailsList.forEach(item => {
        //     tempDetailsList.forEach(tempItem => {
        //         if (item.itemId == tempItem.id) {
        //             item.itemVal = tempItem.itemVal
        //             item.memo = tempItem.memo
        //         }
        //     })
        // })
        this.assessYear = [...new Set(...arrYear)]
        console.log(this.assessYear, '000')
        this.loading = false
      })
    },
    addAcounts() {
      this.params.detailsList.push({
        item: '',
        itemScore: '',
        itemId: '',
        infoId: ''
      })
    },
    handleClose() {
      this.params = {
        detailsList: [],
        reference: '', // 被考核人者
        assessDate: '', // 考核日期
        assessType: '2', // 考核方式（1：单位考核，2：合同考核）
        assessUser: '', // 考核人员
        assessYear: '',
        assessTitle: ''
      }
      this.baseYear = null, //选择年份
        this.activeId = null, //考核标题id
        this.itemsData = []
      this.activeCollapse1 = '1'
      this.visible = false
    },
    goInfo(e) {
      this.$refs.formInfo.validate((valid) => {
        if (valid) {
          if (this.title === '新增') {
            operationCheck.addInfo(this.params, (response) => {
              if (response.state) {
                this.$notify({
                  type: 'success',
                  message: '保存成功',
                  duration: 2000
                })
                this.handleClose()
                this.$parent.loadData(1)
              } else {
              }
            })
          }
          if (this.title === '修改') {
            operationCheck.updateInfo(this.params, (response) => {
              if (response.state) {
                this.$notify({
                  type: 'success',
                  message: '修改成功',
                  duration: 2000
                })
                this.handleClose()
                this.$parent.loadData(1)
              } else {
              }
            })
          }
        } else {
          return false
        }
      })
    },
    // 获取合同考核数据赋值给被考核人，采用下拉选择
    getContractCheckData() {
      let data = {
        assessTitle: this.params.assessTitle,
        assessType: '2',
        assessYear: this.params.assessYear
      }
      operationCheck.getExaminees(data, (res) => {
        this.referenceList = res.value
      })
      // req.contractQuery(this.queryParam).then((res) => {
      //     this.referenceList = res.rows
      // })
    }
  }
}
</script>
<style lang="scss" scoped>
.el-divider--horizontal {
  margin: 24px 0 5px 0;
  height: 7px !important;
  background: #88b4dd !important;

  .el-divider__text {
    font-size: 16px !important;
  }
}

::v-deep .bbsl-scroll-pane .bbsl-scroll-form {
  width: calc(100% - 1.04167vw);
  height: auto;
  overflow-y: auto;
  padding: 0 0.52083vw;
}

::v-deep .el-form-item {
  margin-top: 22px;
}
</style>
<style lang="scss">
.scorll {
  .el-scrollbar__wrap {
    overflow: scroll;
    height: 100%;
  }
}
</style>
